@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991-2006 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 1991-2007 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -22,13 +22,25 @@
   NSColor *bg;
   NSTimer *clockTimer;
   NSTimer *colorTimer;
+  NSTimer *dateTimer;
+  float autoDateInterval;
 
+  BOOL ownWindow;
+  BOOL constrainSizes;
   BOOL usesCountdownTimer;
   NSDate *countdownDate;
   NSColor *initialForegroundColor;
   NSColor *initialBackgroundColor;
 }
 
++ (void)initializeDefaults:(NSUserDefaultsController *)controller;
++ (NSUserDefaultsController *)userDefaultsController;
+
+- (void)setOwnWindow:(BOOL)own_p;
+- (void)setConstrainSizes:(BOOL)constrain_p;
+- (void)setAutoDate:(float)interval;
+- (IBAction) aboutClick: (id)sender;
+
 /* Bindable Properties:
      hourStyle
      timeStyle
