@@ -38,6 +38,35 @@ struct raw_number {
 
 #ifdef BUILTIN_FONTS
 
+# include "zeroB.xbm"
+# include "oneB.xbm"
+# include "twoB.xbm"
+# include "threeB.xbm"
+# include "fourB.xbm"
+# include "fiveB.xbm"
+# include "sixB.xbm"
+# include "sevenB.xbm"
+# include "eightB.xbm"
+# include "nineB.xbm"
+# include "colonB.xbm"
+# include "slashB.xbm"
+
+static struct raw_number numbers_B [] = {
+  { zeroB_bits,  zeroB_width,  zeroB_height  },
+  { oneB_bits,   oneB_width,   oneB_height   },
+  { twoB_bits,   twoB_width,   twoB_height   },
+  { threeB_bits, threeB_width, threeB_height },
+  { fourB_bits,  fourB_width,  fourB_height  },
+  { fiveB_bits,  fiveB_width,  fiveB_height  },
+  { sixB_bits,   sixB_width,   sixB_height   },
+  { sevenB_bits, sevenB_width, sevenB_height },
+  { eightB_bits, eightB_width, eightB_height },
+  { nineB_bits,  nineB_width,  nineB_height  },
+  { colonB_bits, colonB_width, colonB_height },
+  { slashB_bits, slashB_width, slashB_height },
+  { 0, }
+};
+
 # include "zeroC.xbm"
 # include "oneC.xbm"
 # include "twoC.xbm"
@@ -320,7 +349,11 @@ pick_font_size (dali_config *c, unsigned int *w_ret, unsigned int *h_ret)
     default:   abort(); break;
     }
 
-  if      ((w = ((numbers_C[0].width * nn) +
+  if      ((w = ((numbers_B[0].width * nn) +
+                 (numbers_B[10].width * cc))) <= ww &&
+           ((h = numbers_B[0].height) <= hh))
+    f = 4;
+  else if ((w = ((numbers_C[0].width * nn) +
                  (numbers_C[10].width * cc))) <= ww &&
            ((h = numbers_C[0].height) <= hh))
     f = 3;
@@ -367,6 +400,7 @@ init_numbers (dali_config *c)
     case 1: raw = numbers_E; break;
     case 2: raw = numbers_D; break;
     case 3: raw = numbers_C; break;
+    case 4: raw = numbers_B; break;
     default: abort(); break;
     }
 
